@@ -3,8 +3,8 @@
 """imagemv
 
 Usage:
-  imagemv.py SOURCE DEST [--keep=<days>] [--dry-run]
-  imagemv.py SOURCE DEST [--keep-all] [--dry-run]
+  imagemv.py SOURCE DEST [--keep=<days>] [--dry-run] [--verbose]
+  imagemv.py SOURCE DEST [--keep-all] [--dry-run] [--verbose]
   imagemv.py (-h | --help)
   imagemv.py (-v | --version)
 
@@ -59,10 +59,6 @@ def process_dir(src_dir, dest_dir, keep_td, keep_all, dry_run):
                 f"{file_stats.path} -> {f'skipped: {file_stats.skip_reason}' if file_stats.skip_reason else file_stats.target_path}"
             )
 
-        # cleanup: remove all empty directories except source
-        if not dry_run and root != src_dir:
-            remove_empty_dir(root)
-
     stats.finished_at = datetime.now()
     return stats
 
@@ -84,14 +80,6 @@ def process_file(src, dst_dir, keep_td, keep_all, dry_run):
     return stats
 
 
-def remove_empty_dir(directory):
-    logger.debug(f'Removing directory "{directory}" ...')
-    try:
-        os.rmdir(directory)
-    except OSError:
-        logger.debug(f'"{directory}" not removed because it was not empty')
-
-
 def print_stats(stats):
     out = (
         f"Number of files processed: {stats.files_processed}{os.linesep}"
@@ -106,7 +94,7 @@ def print_stats(stats):
 
 def main(arguments=None):
     if not arguments:
-        arguments = docopt(__doc__, version="imagemv 0.3.2")
+        arguments = docopt(__doc__, version="imagemv 0.4.0")
 
     logging.basicConfig(
         level=logging.DEBUG if arguments.get("--verbose") else logging.INFO
